@@ -46,6 +46,10 @@ stopifnot(
     is.na(weights_g2a(NA_real_, na.rm = TRUE))
     is.na(weights_g2a(NaN, na.rm = TRUE))
     is.na(weights_g2a(numeric(0)))
+    is.na(weights_g2a(1:5, 5:1, M = NaN))
+    is.na(weights_g2a(1:5, 5:1, M = Inf))
+    is.na(weights_g2a(1:5, 5:1, M = NA_real_))
+    is.na(weights_g2a(1:5, 5:1, na.rm = TRUE, M = NA_real_))
     identical(is.na(weights_g2a(c(1, NA_real_))), c(TRUE, TRUE))
     identical(is.na(weights_g2a(c(1, NaN))), c(TRUE, TRUE))
     identical(is.na(weights_g2a(c(1, NA_real_), na.rm = TRUE)), c(FALSE, TRUE))
@@ -62,6 +66,7 @@ stopifnot(
     all(weights_factor(x, r = 0) == 1 / length(x))
     all(weights_factor(x, w, r = 0, scale = FALSE) == w)
     all(weights_factor(x, w, r = 1) == x * w / sum(x * w))
+    all(weights_update(x, w) == x * w / sum(x * w))
     # test against a simple implementation
     all(
       vapply(
